@@ -22,10 +22,12 @@
 #ifndef _MAAP_H_
 #define _MAAP_H_
 
+#include <sys/types.h>
+#include <unistd.h>
 #include <stddef.h>
 #include <stdlib.h>
 #include <stdarg.h>
-#include <unistd.h>
+#include <string.h>
 
 #if defined(__INTERIX) && !defined(_ALL_SOURCE)
 /* bug in Interix-3.5 header files? */
@@ -44,6 +46,9 @@ int getopt (int argc, char * const *argv, const char *optstring);
 #include <stdint.h>
 #endif
 
+#if HAVE_INTTYPES_H
+#include <inttypes.h>
+#endif
 #if HAVE_ALLOCA_H
 # include <alloca.h>
 #endif
@@ -65,10 +70,6 @@ int getopt (int argc, char * const *argv, const char *optstring);
 # if HAVE_STRINGS_H
 #  include <strings.h>
 # endif
-# if !defined(HAVE_STRCHR)
-#  define strchr index
-#  define strrchr rindex
-# endif
 # if !defined(HAVE_MEMCPY)
 #  define memcpy(d, s, n) bcopy ((s), (d), (n))
 #  define memmove(d, s, n) bcopy ((s), (d), (n))
@@ -104,13 +105,6 @@ extern unsigned long int strtoul( const char *, char **, int );
 # endif
 #endif
 
-/* Include some standard header files. */
-#include <stdio.h>
-#if HAVE_UNISTD_H
-# include <sys/types.h>
-# include <unistd.h>
-#endif
-
 /* Handle getopt correctly */
 #if HAVE_GETOPT_H
 # include <getopt.h>
